Installation — SQLAlchemy 2.0 Documentation

Release: 2.0.17 | Release Date: June 23, 2023

# SQLAlchemy 2.0 Documentation

# Installation

## I’m getting an error about greenlet not being installed when I try to use asyncio

The `greenlet` dependency does not install by default for CPU architectures for which `greenlet` does not supply a pre-built binary wheel. Notably, this includes Apple M1. To install including `greenlet`, add the `asyncio` setuptools extra to the `pip install` command:

    pip install sqlalchemy[asyncio]

For more background, see Asyncio Platform Installation Notes (Including Apple M1).

See also

Asyncio Platform Installation Notes (Including Apple M1)